# vnai/scope/__init__.py
# Environment detection and state tracking

from vnai.scope.profile import inspector
from vnai.scope.state import tracker, record
from vnai.scope.promo import manager as content_manager
from vnai.scope.promo import present as present_content
